@@ -119,7 +119,23 @@ def change_password(user, password, new_password):
 @cli.command()
 @credential_options
 def generate_api_key(user, password):
-    """Generates a new API key for your account."""
+    """Generates a new API key for your account.
+
+    API keys can simplify access to the cloud API. Keys should be passed in the
+    custom header `Copernic360APIKey` of an https request, as in:
+
+    ```bash
+    > curl -H "Copernic360APIKey XXXXX"
+    ```
+
+    or
+
+    ```python
+    import requests
+
+    requests.get(url=url, headers={"Copernic360APIKey": key})
+    ```
+    """
     public_options.generate_api_key(user, password)
 
 
